# compairingnumber
**This package help you to find greater and smaller number between three numbers

# Getting started
## Installing the Package
> pip install compairingnumber

## using the package
` from HDPACKAGES import python `

# working of package
**the user needs to give three number inputs as x,y,z . theen gives greatest and smallest number among three numbers.
